-- proteaAudio is a free cross-platform 2D audio library for C++ and Lua
-- http://viremo.eludi.net/proteaAudio/
-- v0.6.2
-- proAudioRt.dll has to be placed next to the .lua file

-- function creating a sine wave sample
function sampleSine(freq, duration, sampleRate)
	local data = { }
	for i = 1,duration*sampleRate do
		data[i] = math.sin( (i*freq/sampleRate)*math.pi*2)
	end
	-- proAudio.sampleFromMemory: converts a sound sample to internal audio format
	return proAudio.sampleFromMemory(data, sampleRate)
end

-- plays a sample shifted by a number of halftones for a given duration
function playNote(sample, pitch, duration, volumeL, volumeR, disparity)
	local scale = 2^(pitch/12)
	-- proAudio.soundLoop: plays a specified sample continuously
	-- 		sample - handle returned by the proAudio.sampleFromMemory
	-- 		volumeL - (optional) left volume
	-- 		volumeR - (optional) right volume
	-- 		disparity - (optional) time difference between left and right channel in seconds
	-- 		pitch  - (optional) pitch factor: 0.5 corresponds to one octave below, 2.0 to one above the original sample
	local sound = proAudio.soundLoop(sample, volumeL, volumeR, disparity, scale)
	-- sleep for the given duration to hold the note played by soundLoop
	proAudio.sleep(duration)
	-- stops all the sounds immediately
	proAudio.soundStop(sound)
end

-- create an audio device using default parameters and exit in case of errors
require("proAudioRt")
if not proAudio.create() then os.exit(1) end

-- generate a sample:
local sample = sampleSine(440, 0.5, 88200)

-- end part of the happy birthday song by Brody Janos (or something like that :)..)
for i=1,2 do
	playNote(sample, 12, 0.5)
	playNote(sample, 9, 0.25)
	proAudio.sleep(0.25)

	playNote(sample, 10, 0.5)
	playNote(sample, 14, 0.25)
	proAudio.sleep(0.25)

	playNote(sample, 12, 0.5)
	playNote(sample, 12, 0.25)
	playNote(sample, 12, 0.125)
	playNote(sample, 10, 0.125)

	playNote(sample, 9, 0.25)
	playNote(sample, 10, 0.125)
	playNote(sample, 12, 0.375)
	proAudio.sleep(0.25)

	playNote(sample, 12, 0.25)
	playNote(sample, 12, 0.25)
	playNote(sample, 12, 0.25)
	playNote(sample, 9, 0.25)

	playNote(sample, 10, 0.125)
	playNote(sample, 10, 0.375)
	playNote(sample, 14, 0.5)

	playNote(sample, 12, 0.125)
	playNote(sample, 12, 0.125)
	playNote(sample, 10, 0.25)
	playNote(sample, 9, 0.25)
	playNote(sample, 7, 0.25)
	playNote(sample, 5, 0.375)
	proAudio.sleep(0.75)
end

-- cleanup
proAudio.destroy()
